==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate.md <==
# AmazonAuroraAmazonRdsInstanceAternate


```text
aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate
```

```text
include('aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate')
```



| Illustration | AmazonAuroraAmazonRdsInstanceAternate | AmazonAuroraAmazonRdsInstanceAternateCard | AmazonAuroraAmazonRdsInstanceAternateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate.png) | ![illustration for AmazonAuroraAmazonRdsInstanceAternate](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate.Local.png) | ![illustration for AmazonAuroraAmazonRdsInstanceAternateCard](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternateCard.Local.png) | ![illustration for AmazonAuroraAmazonRdsInstanceAternateGroup](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternateGroup.Local.png) |




## AmazonAuroraAmazonRdsInstanceAternate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonRdsInstanceAternate
include('aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate')

' renders the element
AmazonAuroraAmazonRdsInstanceAternate('AmazonAuroraAmazonRdsInstanceAternate', 'Amazon Aurora Amazon Rds Instance Aternate', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonRdsInstanceAternate
include('aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate')

' renders the element
AmazonAuroraAmazonRdsInstanceAternate('AmazonAuroraAmazonRdsInstanceAternate', 'Amazon Aurora Amazon Rds Instance Aternate', 'an optional tech label')
@enduml
```

## AmazonAuroraAmazonRdsInstanceAternateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonRdsInstanceAternateCard
include('aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate')

' renders the element
AmazonAuroraAmazonRdsInstanceAternateCard('AmazonAuroraAmazonRdsInstanceAternateCard', 'Amazon Aurora Amazon Rds Instance Aternate Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonRdsInstanceAternateCard
include('aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate')

' renders the element
AmazonAuroraAmazonRdsInstanceAternateCard('AmazonAuroraAmazonRdsInstanceAternateCard', 'Amazon Aurora Amazon Rds Instance Aternate Card', 'an optional description')
@enduml
```

## AmazonAuroraAmazonRdsInstanceAternateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonRdsInstanceAternateGroup
include('aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate')

' renders the element
AmazonAuroraAmazonRdsInstanceAternateGroup('AmazonAuroraAmazonRdsInstanceAternateGroup', 'Amazon Aurora Amazon Rds Instance Aternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonRdsInstanceAternateGroup
include('aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate')

' renders the element
AmazonAuroraAmazonRdsInstanceAternateGroup('AmazonAuroraAmazonRdsInstanceAternateGroup', 'Amazon Aurora Amazon Rds Instance Aternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate.md <==
# AmazonAuroraAmazonRdsInstanceAternate


```text
aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate
```

```text
include('aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate')
```



| Illustration | AmazonAuroraAmazonRdsInstanceAternate | AmazonAuroraAmazonRdsInstanceAternateCard | AmazonAuroraAmazonRdsInstanceAternateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate.png) | ![illustration for AmazonAuroraAmazonRdsInstanceAternate](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate.Local.png) | ![illustration for AmazonAuroraAmazonRdsInstanceAternateCard](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternateCard.Local.png) | ![illustration for AmazonAuroraAmazonRdsInstanceAternateGroup](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternateGroup.Local.png) |




## AmazonAuroraAmazonRdsInstanceAternate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonRdsInstanceAternate
include('aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate')

' renders the element
AmazonAuroraAmazonRdsInstanceAternate('AmazonAuroraAmazonRdsInstanceAternate', 'Amazon Aurora Amazon Rds Instance Aternate', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonRdsInstanceAternate
include('aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate')

' renders the element
AmazonAuroraAmazonRdsInstanceAternate('AmazonAuroraAmazonRdsInstanceAternate', 'Amazon Aurora Amazon Rds Instance Aternate', 'an optional tech label')
@enduml
```

## AmazonAuroraAmazonRdsInstanceAternateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonRdsInstanceAternateCard
include('aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate')

' renders the element
AmazonAuroraAmazonRdsInstanceAternateCard('AmazonAuroraAmazonRdsInstanceAternateCard', 'Amazon Aurora Amazon Rds Instance Aternate Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonRdsInstanceAternateCard
include('aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate')

' renders the element
AmazonAuroraAmazonRdsInstanceAternateCard('AmazonAuroraAmazonRdsInstanceAternateCard', 'Amazon Aurora Amazon Rds Instance Aternate Card', 'an optional description')
@enduml
```

## AmazonAuroraAmazonRdsInstanceAternateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonRdsInstanceAternateGroup
include('aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate')

' renders the element
AmazonAuroraAmazonRdsInstanceAternateGroup('AmazonAuroraAmazonRdsInstanceAternateGroup', 'Amazon Aurora Amazon Rds Instance Aternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonRdsInstanceAternateGroup
include('aws-20210730/Resource/Database/AmazonAuroraAmazonRdsInstanceAternate')

' renders the element
AmazonAuroraAmazonRdsInstanceAternateGroup('AmazonAuroraAmazonRdsInstanceAternateGroup', 'Amazon Aurora Amazon Rds Instance Aternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
